# Run this with 'TCLLIBPATH=. tclsh netinfo_test.tcl' to test netinfo.

package require Tcl 8.5
package require tcltest 2.2
namespace import tcltest::*
configure {*}$argv -testdir [file dirname [info script]]

package require netinfo
namespace import netinfo::*


test netinfo-1.1 {netinfo version} -body {
	package provide netinfo
} -result 0.6

test netinfo-1.2 {netinfo exports} -body {
	lsort [namespace eval ::netinfo {
		namespace export
	}]
} -result [list	\
	ether etherData etherDataFilename etherFields \
	host hostData hostDataFilename hostFields \
	loadEtherData loadHostData loadNetworkData loadProtocolData loadServiceData \
	netinfoDatabases network networkData networkDataFilename networkFields \
	protocol protocolData protocolDataFilename protocolFields \
	service serviceData serviceDataFilename serviceFields \
]

test netinfo-1.3 {netinfoDatabases} -body {
	netinfoDatabases
} -result {protocol service network host ether}

test netinfo-1.4 {protocolFields} -body {
	protocolFields
} -result {-name -aliases -comment -number}

test netinfo-1.5 {serviceFields} -body {
	serviceFields
} -result {-name -aliases -comment -port -protocol}

test netinfo-1.6 {networkFields} -body {
	networkFields
} -result {-name -aliases -comment -number}

test netinfo-1.7 {hostFields} -body {
	hostFields
} -result {-name -aliases -comment -address -domain}

test netinfo-1.8 {etherFields} -body {
	etherFields
} -result {-name -address -comment}


foreach db [netinfoDatabases] {
	testConstraint $db [file exists [${db}DataFilename]]
}


test netinfo-2.1 {loadProtocolData} -body {
	loadProtocolData
} -result {} -constraints {protocol}

test netinfo-2.2 {loadServiceData} -body {
	loadServiceData
} -result {} -constraints {service}

test netinfo-2.3 {loadNetworkData} -body {
	loadNetworkData
} -result {} -constraints {network}

test netinfo-2.4 {loadHostData} -body {
	loadHostData
} -result {} -constraints {host}

test netinfo-2.5 {loadEtherData} -body {
	loadEtherData
} -result {} -constraints {ether}


test netinfo-10.1 {getServiceByPort} -constraints {service} -body {
	service -port 18 -protocol tcp
} -result {msp {} {message send protocol} 18 tcp}

test netinfo-10.2 {getServiceByPort} -constraints {service} -body {
	service -port 25 -protocol tcp
} -result {smtp mail {} 25 tcp}


test netinfo-internal-1.1 {StrDivideAtStr} -body {
	::netinfo::StrDivideAtStr "abc"
} -result {abc {}}

test netinfo-internal-1.2 {StrDivideAtStr} -body {
	::netinfo::StrDivideAtStr "abc#"
} -result {abc {}}

test netinfo-internal-1.3 {StrDivideAtStr} -body {
	::netinfo::StrDivideAtStr "#def"
} -result {{} def}

test netinfo-internal-1.4 {StrDivideAtStr} -body {
	::netinfo::StrDivideAtStr "abc#def"
} -result {abc def}

test netinfo-internal-1.5 {StrDivideAtStr} -body {
	::netinfo::StrDivideAtStr "abcxyzdef" xyz
} -result {abc def}


cleanupTests


# EOF
